@@ -1,3 +1,3 @@
 from . import vacancy_predictors_classified
 from . import vacancy_predictors
-from . import math_finger
\ No newline at end of file
+from . import mach_finger
\ No newline at end of file
